@@ -57,12 +57,17 @@ func (e *Exporter) scrapeHandler(w http.ResponseWriter, r *http.Request) {
 		return
 	}
 
-	// get rid of username/password info in "target" so users don't send them in plain text via http
-	u.User = nil
-	target = u.String()
-
 	opts := e.options
 
+	// get rid of username/password info in "target" so users don't send them in plain text via http
+	// and save "user" in options so we can use it later when connecting to the redis instance
+	// the password will be looked up from the password file
+	if u.User != nil {
+		opts.User = u.User.Username()
+		u.User = nil
+	}
+	target = u.String()
+
 	if ck := r.URL.Query().Get("check-keys"); ck != "" {
 		opts.CheckKeys = ck
 	}
